/**
 * Copyright (C) 2016-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.ui.context;

import java.util.LinkedHashMap;
import java.util.Map;

import org.dussan.vaadin.dtabs.demo.tabs.BottomTabs;
import org.dussan.vaadin.dtabs.demo.tabs.TopTabs;
import org.dussan.vaadin.dtabs.demo.tabs.summary.TabsSummary;
import org.dussan.vaadin.dtabs.demo.ui.tree.TabTypes;
import org.dussan.vaadin.dtabs.demo.ui.tree.TabsTree;

import com.vaadin.ui.Component;
import com.vaadin.ui.VerticalLayout;

public class ContextLayout
    extends VerticalLayout
{

    private static final long serialVersionUID = 682225016379675172L;

    private boolean isAttached = false;

    private Component activeComponent = null;

    private void init()
    {
        setStyleName( "tabContext" );
        setMargin( true );
        activeComponent = new TabsSummary( addTabs() );
        addComponent( activeComponent );
    }

    private void replaceActiveComponent( Component newComponent )
    {
        if ( !activeComponent.equals( newComponent ) )
        {
            removeComponent( activeComponent );
            activeComponent = newComponent;
            addComponent( activeComponent );
        }
    }

    private Map<String, Map<String, String[]>> addTabs()
    {
        Map<String, Map<String, String[]>> tabs = new LinkedHashMap<String, Map<String, String[]>>();
        tabs.put( TabTypes.TOP.getPath(), TopTabs.getTabs() );
        tabs.put( TabTypes.BOTTOM.getPath(), BottomTabs.getTabs() );
        return tabs;
    }

    public void processChangedFragment( String fragment )
    {
        String tabType = fragment.isEmpty() ? fragment : fragment.split( TabsTree.PATH_DELIMITER )[0];
        String tab = ( !fragment.isEmpty() && fragment.contains( TabsTree.PATH_DELIMITER ) )
                        ? fragment.split( TabsTree.PATH_DELIMITER )[1] : new String();

        Component tempComponent = null;
        switch ( TabTypes.fromString( tabType ) )
        {
            case TOP:
                tempComponent = TopTabs.processTab( tab );
                break;
            case BOTTOM:
                tempComponent = BottomTabs.processTab( tab );
                break;
            case DEFAULT:
            default:
                tempComponent = new TabsSummary( addTabs() );
                break;
        }
        replaceActiveComponent( tempComponent );
    }

    @Override
    public void attach()
    {
        super.attach();
        if ( !isAttached )
        {
            isAttached = true;
            init();
        }
    }

    @Override
    public void detach()
    {
        super.detach();
        if ( isAttached )
        {
            isAttached = false;
        }
    }

}
